@@ -618,11 +618,6 @@ eog_image_get_file_info (EogImage *img,
 
 		if (mime_type)
 			*mime_type = NULL;
-
-		g_set_error (error,
-			     EOG_IMAGE_ERROR,
-			     EOG_IMAGE_ERROR_VFS,
-			     "Error in getting image file info");
 	} else {
 		if (bytes)
 			*bytes = g_file_info_get_size (file_info);
@@ -1965,7 +1960,7 @@ eog_image_save_as_by_info (EogImage *img, EogImageSaveInfo *source, EogImageSave
 		success = gdk_pixbuf_save (priv->image, tmp_file_path, target->format, error, NULL);
 	}
 
-	if (success && !direct_copy) { /* not required if we alredy copied the file directly */
+	if (success && !direct_copy) { /* not required if we already copied the file directly */
 		/* try to move result file to target uri */
 		success = tmp_file_move_to_uri (img, tmp_file, target->file, target->overwrite, error);
 	}
